.. TestTF documentation master file, created by
   sphinx-quickstart on Fri Feb 16 17:39:32 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to TestTF's documentation!
==================================

.. toctree::
   :maxdepth: 4

   matching
   classif
   datasets

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
